3.8.3. pypago.plot.contourplot — PyPAGO 1.0.1 documentation

# 3.8.3. pypago.plot.contourplot

`pypago.plot.` `contourplot`(secstruct, vartoplot, istracer, itime=None, ax=None, **kwargs)

  Contourplot of a variable contained in a gridded section.

  Parameters: | secstruct (pypago.sections.GridSection) – Gridded section vartoplot (str) – Variable to plot istracer (bool) – True if tracer field (i.e. temperature), False if velocity field (or transport field). itime (int) – Time index to extract. If None, temporal mean is computed ax (ax) – Axis. If None, gca()
  Returns: | cs, cb